@@ -398,7 +398,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             cf = open(homedir + '/.config/.gqrxHamlib.config', 'r')
         except IOError:
             cf = open(homedir + '/.config/.gqrxHamlib.config', 'w+')
-            configLine = '127.0.0.1,7356,127.0.0.1,4532,127.0.0.1,7362,N,Y,N,0'
+            configLine = '127.0.0.1,7356,127.0.0.1,4532,Y,N,0'
             cf.write(configLine)
             cf.close()
             cf = open(homedir + '/.config/.gqrxHamlib.config', 'r')
